@@ -95,7 +95,9 @@ namespace smc {
         ///The particles within the system.
         population<Space> pPopulation;
         ///The set of moves available.
-        moveset<Space,Params> Moves;
+        moveset<Space,Params>* pMoves;
+        ///A flag to track whether the moveset object needs to be included in this destructor.
+        bool movesetBelong;
         /// The additional algorithm parameters.
         Params algParams;
         /// An object for adapting additional algorithm parameters
@@ -129,6 +131,8 @@ namespace smc {
     public:
         ///Create an particle system containing lSize uninitialised particles with the specified mode.
         sampler(long lSize, HistoryType::Enum htHistoryMode);
+        ///Create an particle system containing lSize uninitialised particles with the specified mode.
+        sampler(long lSize, HistoryType::Enum htHistoryMode, moveset<Space,Params>*);
         ///Dispose of a sampler.
         ~sampler();
         ///Copy constructor
@@ -200,7 +204,9 @@ namespace smc {
         ///Resample the particle set using the specified resampling scheme.
         void Resample(ResampleType::Enum lMode);
         ///Sets the entire moveset to the one which is supplied
-        void SetMoveSet(moveset<Space,Params>& pNewMoveset) { Moves = pNewMoveset; }
+        void SetMoveSet(moveset<Space,Params>* pNewMoves) {delete pMoves; pMoves = pNewMoves; movesetBelong = 0;}
+        ///Sets the entire moveset to the one which is supplied - backwards compatibility
+        void SetMoveSet(moveset<Space,Params> & NewMoves) {delete pMoves; pMoves = &NewMoves; movesetBelong = 0;}
         ///Set Resampling Parameters
         void SetResampleParams(ResampleType::Enum rtMode, double dThreshold);
         ///Set additional algorithm parameters
@@ -223,6 +229,36 @@ namespace smc {
         double CalcLogNC(void) const {return stableLogSumWeights(pPopulation.GetLogWeight());}
     };
 
+    /// The constructor prepares a sampler for use but does not assign any moves to the moveset, initialise the particles
+    /// or otherwise perform any sampling related tasks. Its main function is to allocate a region of memory in which to
+    /// store the particle set.
+    ///
+    /// \param lSize The number of particles present in the ensemble (at time 0 if this is a variable quantity)
+    /// \param htHM The history mode to use: set this to HistoryType::RAM to store the whole history of the system and SMC_HISTORY_NONE to avoid doing so.
+    /// \param pNewMoves Pointer to a moveset.
+    /// \tparam Space The class used to represent a point in the sample space.
+    /// \tparam Params (optional) The class used for any additional parameters.
+    template <class Space, class Params>
+    sampler<Space,Params>::sampler(long lSize, HistoryType::Enum htHM, moveset<Space,Params>* pNewMoves)
+    {
+        N = lSize;
+        uRSCount = arma::zeros<arma::Col<int> >(static_cast<int>(N));
+
+        //Some workable defaults.
+        htHistoryMode = htHM;
+        rtResampleMode = ResampleType::STRATIFIED;;
+        dResampleThreshold = 0.5 * N;
+
+        //Create an empty adaptation object by default
+        pAdapt = new adaptMethods<Space,Params>;
+        adaptBelong = 1;
+        nRepeats = 1;
+
+		// Adding the moveset
+		pMoves = pNewMoves;
+		movesetBelong = 0;
+    }
+
     /// The constructor prepares a sampler for use but does not assign any moves to the moveset, initialise the particles
     /// or otherwise perform any sampling related tasks. Its main function is to allocate a region of memory in which to
     /// store the particle set.
@@ -246,6 +282,10 @@ namespace smc {
         pAdapt = new adaptMethods<Space,Params>;
         adaptBelong = 1;
         nRepeats = 1;
+
+		// Creating a default moveset
+        pMoves = new moveset<Space,Params>;
+        movesetBelong = 1;
     }
 
     template <class Space, class Params>
@@ -253,6 +293,8 @@ namespace smc {
     {
         if(adaptBelong)
         delete pAdapt;
+        if(movesetBelong)
+        delete pMoves;
     }
 
     // deep-copy, to be used both for copy constructor and assignment overload.
@@ -278,8 +320,24 @@ namespace smc {
 
         ///The particles within the system.
         pPopulation = sFrom.pPopulation;
-        ///The set of moves available.
-        Moves = sFrom.Moves;
+        ///The set of moves.
+        if(sFrom.movesetBelong) {
+            // this can only happen if the default moveset was used,
+            // i.e., no call to SetMoveSet
+            pMoves = new moveset<Space,Params>;
+            movesetBelong = 1;
+        } else {
+            // this can only happen if SetMoveSet was called,
+            // i.e., pMoves points to an external object which should not be deleted with sampler
+            pMoves = sFrom.pMoves;
+            movesetBelong = 0;
+        }
+        // /// Moveset object
+        // pMoves = sFrom.pMoves;
+        // ///A flag to track whether the moveset object needs to be included in this destructor.
+        // movesetBelong = sFrom.movesetBelong sFrom.movesetBelong;
+
+
         /// The additional algorithm parameters.
         algParams = sFrom.algParams;
         if(sFrom.adaptBelong) {
@@ -332,6 +390,9 @@ namespace smc {
           if (adaptBelong) {
             delete pAdapt;
           }
+          if (movesetBelong) {
+            delete pMoves;
+          }
           _copy(sFrom);
         }
         return *this;
@@ -358,7 +419,7 @@ namespace smc {
         std::vector<Space> InitVal(N);
         arma::vec InitWeights(N);
         pPopulation = population<Space>(InitVal,InitWeights);
-        Moves.DoInit(pPopulation,N,algParams);
+        pMoves->DoInit(pPopulation,N,algParams);
 
         //Scaling weights by 1/N (for evidence computation)
         pPopulation.SetLogWeight(pPopulation.GetLogWeight() - log(static_cast<double>(N)));
@@ -384,7 +445,7 @@ namespace smc {
         }
 
         //A possible MCMC step should be included here.
-        bool didMCMC =  Moves.DoMCMC(0,pPopulation, N, nRepeats, nAccepted,algParams);
+        bool didMCMC =  pMoves->DoMCMC(0,pPopulation, N, nRepeats, nAccepted,algParams);
         if (didMCMC){
             acceptProb = static_cast<double>(nAccepted)/(static_cast<double>(N)*static_cast<double>(nRepeats));
         }
@@ -584,7 +645,7 @@ namespace smc {
         }
 
         //A possible MCMC step should be included here.
-        bool didMCMC = Moves.DoMCMC(T+1,pPopulation, N, nRepeats, nAccepted,algParams);
+        bool didMCMC = pMoves->DoMCMC(T+1,pPopulation, N, nRepeats, nAccepted,algParams);
         if (didMCMC){
             acceptProb = static_cast<double>(nAccepted)/(static_cast<double>(N)*static_cast<double>(nRepeats));
         }
@@ -618,7 +679,7 @@ namespace smc {
     template <class Space, class Params>
     void sampler<Space,Params>::MoveParticles(void)
     {
-        Moves.DoMove(T+1,pPopulation, N,algParams);
+        pMoves->DoMove(T+1,pPopulation, N,algParams);
     }
 
     template <class Space, class Params>
